# Moteur

OpenMV dispose de ports IO et peut piloter divers moteurs.

## moteur pas à pas

### Qu'est-ce qu'un moteur pas à pas

Le moteur pas à pas est un moteur de contrôle en boucle ouverte qui convertit
les signaux d'impulsion électrique en déplacement angulaire ou en déplacement
linéaire. Il constitue le principal élément exécutif des systèmes de contrôle de
programme numérique modernes et est largement utilisé.

Tels que les imprimantes 3D et les bras robotiques.

### Carte pilote de moteur pas à pas

De nombreuses puces et modules peuvent contrôler les moteurs pas à pas. Nous
utilisons un module très simple, EasyDriver.

Pour faire simple, la direction est contrôlée par dir. Si une impulsion est
donnée à step le moteur avancera d'un pas.

![](/assets/06-07-001.jpg)

### Connecter

![](/assets/06-07-002.jpg)

## Installer le module

[Le code du module est dans ce
lien](http://book.openmv.cc/module/write-module-motor.html)

Enregistrez le code de cette classe sous forme de fichier stepper.py et
placez-le dans le répertoire racine d'OpenMV.

## code

```python
# 步进电机控制 - By: 小智智- 周日 4月 2 2017

from pyb import Pin

from stepper import Stepper

import time

step_pin = Pin('P0')
dir_pin = Pin('P1')

my_stepper = Stepper(step_pin,dir_pin)

print("relative angle move test begin:", my_stepper.read_pos())
my_stepper.rel_angle(180)#相对角度控制
print("relative angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("steps angle move test end:", my_stepper.read_pos())
my_stepper.steps(-400)#步进脉冲控制
print("steps angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("absolute angle move test begin:", my_stepper.read_pos())
my_stepper.abs_angle(0)#绝对角度控制
print("absolute angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)
```

## Moteur à courant continu

#### Tutoriel 26 – La version d'extension du moteur contrôle le moteur à courant continu : [https://singtown.com/video](https://singtown.com/video)

### Qu'est-ce qu'un moteur à courant continu

La vitesse d'un moteur à courant continu est directement proportionnelle à la
tension.

### Carte pilote

De nombreuses cartes pilotes peuvent piloter des moteurs à courant continu, nous
utilisons ici le TB6612FNG, double pont en H.

![](/assets/06-07-003.jpg)

### Connecter

![](/assets/06-07-004.jpg)

### code

```python
待添加
```

## appareil à gouverner

OpenMV2 a deux broches de servo, P7 , P8

OpenMV3 a trois broches de servo, P7, P8, P9

### Connecter

![](/assets/06-07-005.jpg)

### Vérifier l'alimentation

Le servo est un appareil à fort courant et doit utiliser une alimentation
externe (alimentation régulée, batterie lithium...). L'USB ne peut pas alimenter
le servo !

### code

```python
# Servo Control Example
#
# This example shows how to use your OpenMV Cam to control servos.

import time
from pyb import Servo

s1 = Servo(1) # P7
s2 = Servo(2) # P8
#s3 = Servo(3) # P9 Only for OpenMV3 M7
while(True):
    for i in range(-90,90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
    for i in range(90,-90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
```

## PCA9685 connecte plusieurs servos

Lien bébé :
[https://singtown.com/product/49277](https://singtown.com/product/49277)

#### Tutoriel vidéo 25 - Le pca9685 contrôle plusieurs servos : [https://singtown.com/learn/50057/](https://singtown.com/learn/50057/)



Le module PCA9685, utilisant seulement 2 broches (protocole I2C), peut contrôler
16 canaux PWM, soit 16 servos ou 16 lumières LED. Vous pouvez même connecter 62
modules tout en n'utilisant que 2 broches pour contrôler 992 PWM !

Connecter

![](/assets/06-07-006-01.jpg)

code

![](/assets/06-07-007.jpg)

Cliquez pour exécuter

